'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.styleToFuncMap = undefined;
exports.alignContent = alignContent;
exports.alignItems = alignItems;
exports.alignSelf = alignSelf;
exports.aspectRatio = aspectRatio;
exports.borderBottomWidth = borderBottomWidth;
exports.borderEndWidth = borderEndWidth;
exports.borderLeftWidth = borderLeftWidth;
exports.borderRightWidth = borderRightWidth;
exports.borderStartWidth = borderStartWidth;
exports.borderTopWidth = borderTopWidth;
exports.borderWidth = borderWidth;
exports.display = display;
exports.flex = flex;
exports.flexBasis = flexBasis;
exports.flexDirection = flexDirection;
exports.flexGrow = flexGrow;
exports.flexShrink = flexShrink;
exports.flexWrap = flexWrap;
exports.height = height;
exports.justifyContent = justifyContent;
exports.marginBottom = marginBottom;
exports.marginEnd = marginEnd;
exports.marginLeft = marginLeft;
exports.marginRight = marginRight;
exports.marginStart = marginStart;
exports.marginTop = marginTop;
exports.marginHorizontal = marginHorizontal;
exports.marginVertical = marginVertical;
exports.margin = margin;
exports.maxHeight = maxHeight;
exports.maxWidth = maxWidth;
exports.minHeight = minHeight;
exports.minWidth = minWidth;
exports.overflow = overflow;
exports.paddingBottom = paddingBottom;
exports.paddingEnd = paddingEnd;
exports.paddingLeft = paddingLeft;
exports.paddingRight = paddingRight;
exports.paddingStart = paddingStart;
exports.paddingTop = paddingTop;
exports.paddingHorizontal = paddingHorizontal;
exports.paddingVertical = paddingVertical;
exports.padding = padding;
exports.position = position;
exports.bottom = bottom;
exports.end = end;
exports.left = left;
exports.right = right;
exports.start = start;
exports.top = top;
exports.width = width;

var _yogaLayout = require('yoga-layout');

var _yogaLayout2 = _interopRequireDefault(_yogaLayout);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var styleToFuncMap = exports.styleToFuncMap = {
  alignContent: alignContent,
  alignItems: alignItems,
  alignSelf: alignSelf,

  aspectRatio: aspectRatio,

  borderBottomWidth: borderBottomWidth,
  borderEndWidth: borderEndWidth,
  borderLeftWidth: borderLeftWidth,
  borderRightWidth: borderRightWidth,
  borderStartWidth: borderStartWidth,
  borderTopWidth: borderTopWidth,
  borderWidth: borderWidth,

  display: display,
  flex: flex,
  flexBasis: flexBasis,
  flexDirection: flexDirection,
  flexGrow: flexGrow,
  flexShrink: flexShrink,
  flexWrap: flexWrap,
  height: height,
  justifyContent: justifyContent,

  marginBottom: marginBottom,
  marginEnd: marginEnd,
  marginLeft: marginLeft,
  marginRight: marginRight,
  marginStart: marginStart,
  marginTop: marginTop,
  marginHorizontal: marginHorizontal,
  marginVertical: marginVertical,
  margin: margin,

  maxHeight: maxHeight,
  maxWidth: maxWidth,
  minHeight: minHeight,
  minWidth: minWidth,

  paddingBottom: paddingBottom,
  paddingEnd: paddingEnd,
  paddingLeft: paddingLeft,
  paddingRight: paddingRight,
  paddingStart: paddingStart,
  paddingTop: paddingTop,
  paddingHorizontal: paddingHorizontal,
  paddingVertical: paddingVertical,
  padding: padding,

  position: position,
  bottom: bottom,
  end: end,
  left: left,
  right: right,
  start: start,
  top: top,

  width: width
};

// Constant maps

var alignMap = {
  auto: _yogaLayout2.default.ALIGN_AUTO,
  'flex-start': _yogaLayout2.default.ALIGN_FLEX_START,
  'flex-end': _yogaLayout2.default.ALIGN_FLEX_END,
  center: _yogaLayout2.default.ALIGN_CENTER,
  stretch: _yogaLayout2.default.ALIGN_STRETCH,
  'space-between': _yogaLayout2.default.ALIGN_SPACE_BETWEEN,
  'space-around': _yogaLayout2.default.ALIGN_SPACE_AROUND,
  baseline: _yogaLayout2.default.ALIGN_BASELINE
};

var displayMap = {
  none: _yogaLayout2.default.DISPLAY_NONE,
  flex: _yogaLayout2.default.DISPLAY_FLEX
};

var flexDirectionMap = {
  row: _yogaLayout2.default.FLEX_DIRECTION_ROW,
  'row-reverse': _yogaLayout2.default.FLEX_DIRECTION_ROW_REVERSE,
  column: _yogaLayout2.default.FLEX_DIRECTION_COLUMN,
  'column-reverse': _yogaLayout2.default.FLEX_DIRECTION_COLUMN_REVERSE
};

var flexWrapMap = {
  wrap: _yogaLayout2.default.WRAP_WRAP,
  nowrap: _yogaLayout2.default.WRAP_NO_WRAP
};

var justifyContentMap = {
  'flex-start': _yogaLayout2.default.JUSTIFY_FLEX_START,
  'flex-end': _yogaLayout2.default.JUSTIFY_FLEX_END,
  center: _yogaLayout2.default.JUSTIFY_CENTER,
  'space-between': _yogaLayout2.default.JUSTIFY_SPACE_BETWEEN,
  'space-around': _yogaLayout2.default.JUSTIFY_SPACE_AROUND,
  'space-evenly': _yogaLayout2.default.JUSTIFY_SPACE_EVENLY
};

var overflowMap = {
  visible: _yogaLayout2.default.OVERFLOW_VISIBLE,
  hidden: _yogaLayout2.default.OVERFLOW_HIDDEN,
  scroll: _yogaLayout2.default.OVERFLOW_SCROLL
};

var positionTypeMap = {
  absolute: _yogaLayout2.default.POSITION_TYPE_ABSOLUTE,
  relative: _yogaLayout2.default.POSITION_TYPE_RELATIVE
};

function alignContent(node, value) {
  if (value in alignMap) {
    node.setAlignContent(alignMap[value]);
  }
}

function alignItems(node, value) {
  if (value in alignMap) {
    node.setAlignItems(alignMap[value]);
  }
}

function alignSelf(node, value) {
  if (value in alignMap) {
    node.setAlignSelf(alignMap[value]);
  }
}

function aspectRatio(node, value) {
  node.setAspectRatio(value);
}

function borderBottomWidth(node, value) {
  node.setBorder(_yogaLayout2.default.EDGE_BOTTOM, value);
}

function borderEndWidth(node, value) {
  node.setBorder(_yogaLayout2.default.EDGE_END, value);
}

function borderLeftWidth(node, value) {
  node.setBorder(_yogaLayout2.default.EDGE_LEFT, value);
}

function borderRightWidth(node, value) {
  node.setBorder(_yogaLayout2.default.EDGE_RIGHT, value);
}

function borderStartWidth(node, value) {
  node.setBorder(_yogaLayout2.default.EDGE_START, value);
}

function borderTopWidth(node, value) {
  node.setBorder(_yogaLayout2.default.EDGE_TOP, value);
}

function borderWidth(node, value) {
  node.setBorder(_yogaLayout2.default.EDGE_ALL, value);
}

function display(node, value) {
  if (value in displayMap) {
    node.setDisplay(displayMap[value]);
  }
}

function flex(node, value) {
  node.setFlex(value);
}

function flexBasis(node, value) {
  node.setFlexBasis(value);
}

function flexDirection(node, value) {
  if (value in flexDirectionMap) {
    node.setFlexDirection(flexDirectionMap[value]);
  }
}

function flexGrow(node, value) {
  node.setFlexGrow(value);
}

function flexShrink(node, value) {
  node.setFlexShrink(value);
}

function flexWrap(node, value) {
  if (value in flexWrapMap) {
    node.setFlexWrap(flexWrapMap[value]);
  }
}

function height(node, value) {
  node.setHeight(value);
}

function justifyContent(node, value) {
  if (value in justifyContentMap) {
    node.setJustifyContent(justifyContentMap[value]);
  }
}

function marginBottom(node, value) {
  node.setMargin(_yogaLayout2.default.EDGE_BOTTOM, value);
}

function marginEnd(node, value) {
  node.setMargin(_yogaLayout2.default.EDGE_END, value);
}

function marginLeft(node, value) {
  node.setMargin(_yogaLayout2.default.EDGE_LEFT, value);
}

function marginRight(node, value) {
  node.setMargin(_yogaLayout2.default.EDGE_RIGHT, value);
}

function marginStart(node, value) {
  node.setMargin(_yogaLayout2.default.EDGE_START, value);
}

function marginTop(node, value) {
  node.setMargin(_yogaLayout2.default.EDGE_TOP, value);
}

function marginHorizontal(node, value) {
  node.setMargin(_yogaLayout2.default.EDGE_HORIZONTAL, value);
}

function marginVertical(node, value) {
  node.setMargin(_yogaLayout2.default.EDGE_VERTICAL, value);
}

function margin(node, value) {
  node.setMargin(_yogaLayout2.default.EDGE_ALL, value);
}

function maxHeight(node, value) {
  node.setMaxHeight(value);
}

function maxWidth(node, value) {
  node.setMaxWidth(value);
}

function minHeight(node, value) {
  node.setMinHeight(value);
}

function minWidth(node, value) {
  node.setMinWidth(value);
}

function overflow(node, value) {
  if (value in overflowMap) {
    node.setOverflow(overflowMap[value]);
  }
}

function paddingBottom(node, value) {
  node.setPadding(_yogaLayout2.default.EDGE_BOTTOM, value);
}

function paddingEnd(node, value) {
  node.setPadding(_yogaLayout2.default.EDGE_END, value);
}

function paddingLeft(node, value) {
  node.setPadding(_yogaLayout2.default.EDGE_LEFT, value);
}

function paddingRight(node, value) {
  node.setPadding(_yogaLayout2.default.EDGE_RIGHT, value);
}

function paddingStart(node, value) {
  node.setPadding(_yogaLayout2.default.EDGE_START, value);
}

function paddingTop(node, value) {
  node.setPadding(_yogaLayout2.default.EDGE_TOP, value);
}

function paddingHorizontal(node, value) {
  node.setPadding(_yogaLayout2.default.EDGE_HORIZONTAL, value);
}

function paddingVertical(node, value) {
  node.setPadding(_yogaLayout2.default.EDGE_VERTICAL, value);
}

function padding(node, value) {
  node.setPadding(_yogaLayout2.default.EDGE_ALL, value);
}

function position(node, value) {
  if (value in positionTypeMap) {
    node.setPositionType(positionTypeMap[value]);
  }
}

function bottom(node, value) {
  node.setPosition(_yogaLayout2.default.EDGE_BOTTOM, value);
}

function end(node, value) {
  node.setPosition(_yogaLayout2.default.EDGE_END, value);
}

function left(node, value) {
  node.setPosition(_yogaLayout2.default.EDGE_LEFT, value);
}

function right(node, value) {
  node.setPosition(_yogaLayout2.default.EDGE_RIGHT, value);
}

function start(node, value) {
  node.setPosition(_yogaLayout2.default.EDGE_START, value);
}

function top(node, value) {
  node.setPosition(_yogaLayout2.default.EDGE_TOP, value);
}

function width(node, value) {
  node.setWidth(value);
}